summaryrefslogtreecommitdiff
path: root/sd/source/ui/view/DocumentRenderer.cxx
diff options
context:
space:
mode:
authorPhilipp Lohmann <pl@openoffice.org>2009-08-19 09:37:10 +0000
committerPhilipp Lohmann <pl@openoffice.org>2009-08-19 09:37:10 +0000
commit3bdbe5e1d0d6dc56f2b4f4c5574168fa3eb587d7 (patch)
tree23cd95ea4c94eaa8df45459b9fb4637f573b3b8f /sd/source/ui/view/DocumentRenderer.cxx
parent9be3c3724cd0dd2409ac1ebba88d30e04127272c (diff)
use correct property names
Diffstat (limited to 'sd/source/ui/view/DocumentRenderer.cxx')
-rw-r--r--sd/source/ui/view/DocumentRenderer.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/sd/source/ui/view/DocumentRenderer.cxx b/sd/source/ui/view/DocumentRenderer.cxx
index dc8a1c590bc9..75452c740366 100644
--- a/sd/source/ui/view/DocumentRenderer.cxx
+++ b/sd/source/ui/view/DocumentRenderer.cxx
@@ -187,13 +187,13 @@ namespace {
bool IsPrintFrontPage (void) const
{
- sal_Int32 nInclude = static_cast<sal_Int32>(mrProperties.getIntValue( "PrintPropspectInclude", 0 ));
+ sal_Int32 nInclude = static_cast<sal_Int32>(mrProperties.getIntValue( "PrintProspectInclude", 0 ));
return nInclude == 0 || nInclude == 1;
}
bool IsPrintBackPage (void) const
{
- sal_Int32 nInclude = static_cast<sal_Int32>(mrProperties.getIntValue( "PrintPropspectInclude", 0 ));
+ sal_Int32 nInclude = static_cast<sal_Int32>(mrProperties.getIntValue( "PrintProspectInclude", 0 ));
return nInclude == 0 || nInclude == 2;
}
@@ -547,7 +547,7 @@ namespace {
if( mbImpress )
{
// FIXME: additional dependency on PrintPropspect = false
vcl::PrinterOptionsHelper::UIControlOptions
aPageOptionsOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PageContentType" ) ), 0 );
AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
@@ -564,7 +564,7 @@ namespace {
else
{
vcl::PrinterOptionsHelper::UIControlOptions
- aPageOptionsOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintPropspect" ) ), sal_False );
+ aPageOptionsOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspect" ) ), sal_False );
AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
rtl::OUString(),
CreateChoice(_STR_IMPRESS_PRINT_UI_PAGE_OPTIONS_CHOICES_HELP),
@@ -582,7 +582,7 @@ namespace {
AddDialogControl( vcl::PrinterOptionsHelper::getBoolControlOpt(
String( SdResId(_STR_IMPRESS_PRINT_UI_BROCHURE) ),
String( SdResId(_STR_IMPRESS_PRINT_UI_BROCHURE_HELP) ),
- OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintPropspect" ) ),
+ OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspect" ) ),
sal_False,
aBrochureOpt
)
@@ -593,11 +593,11 @@ namespace {
aBrochureOpt ) );
vcl::PrinterOptionsHelper::UIControlOptions
- aIncludeOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintPropspect" ) ), -1, sal_False );
+ aIncludeOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspect" ) ), -1, sal_False );
AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
String( SdResId(_STR_IMPRESS_PRINT_UI_BROCHURE_INCLUDE) ),
CreateChoice(_STR_IMPRESS_PRINT_UI_BROCHURE_INCLUDE_LIST_HELP),
- OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintPropspectInclude" ) ),
+ OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspectInclude" ) ),
CreateChoice(_STR_IMPRESS_PRINT_UI_BROCHURE_INCLUDE_LIST),
0,
OUString( RTL_CONSTASCII_USTRINGPARAM( "List" ) ),
@@ -547,7 +547,7 @@ namespace {
if( mbImpress )
{
- // FIXME: additional dependency on PrintPropspect = false
+ // FIXME: additional dependency on PrintProspect = false
vcl::PrinterOptionsHelper::UIControlOptions
aPageOptionsOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PageContentType" ) ), 0 );